==> physx-jni-0.4.1-sources.jar: physx/physics/PxActorShape.java <==
package physx.physics;

import physx.NativeObject;

public class PxActorShape extends NativeObject {

    protected PxActorShape() { }

    public static PxActorShape wrapPointer(long address) {
        return address != 0L ? new PxActorShape(address) : null;
    }
    
    protected PxActorShape(long address) {
        super(address);
    }

    // Destructor

    public void destroy() {
        if (address == 0L) {
            throw new IllegalStateException(this + " is already deleted");
        }
        if (isExternallyAllocated) {
            throw new IllegalStateException(this + " is externally allocated and cannot be manually destroyed");
        }
        _delete_native_instance(address);
        address = 0L;
    }
    private static native long _delete_native_instance(long address);

    // Attributes

    /**
     * @return WebIDL type: {@link PxRigidActor}
     */
    public PxRigidActor getActor() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return PxRigidActor.wrapPointer(_getActor(address));
    }
    private static native long _getActor(long address);

    /**
     * @param value WebIDL type: {@link PxRigidActor}
     */
    public void setActor(PxRigidActor value) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setActor(address, value.getAddress());
    }
    private static native void _setActor(long address, long value);

    /**
     * @return WebIDL type: {@link PxShape}
     */
    public PxShape getShape() {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        return PxShape.wrapPointer(_getShape(address));
    }
    private static native long _getShape(long address);

    /**
     * @param value WebIDL type: {@link PxShape}
     */
    public void setShape(PxShape value) {
        if (address == 0L) {
            throw new NullPointerException("Native address of " + this + " is 0");
        }
        _setShape(address, value.getAddress());
    }
    private static native void _setShape(long address, long value);

}

==> physx-jni-0.4.14-sources.jar: physx/physics/PxActorShape.java <==
package physx.physics;

import physx.NativeObject;

public class PxActorShape extends NativeObject {

    protected PxActorShape() { }

    public static PxActorShape wrapPointer(long address) {
        return address != 0L ? new PxActorShape(address) : null;
    }
    
    protected PxActorShape(long address) {
        super(address);
    }

    // Destructor

    public void destroy() {
        if (address == 0L) {
            throw new IllegalStateException(this + " is already deleted");
        }
        if (isExternallyAllocated) {
            throw new IllegalStateException(this + " is externally allocated and cannot be manually destroyed");
        }
        _delete_native_instance(address);
        address = 0L;
    }
    private static native long _delete_native_instance(long address);

    // Attributes

    /**
     * @return WebIDL type: {@link PxRigidActor}
     */
    public PxRigidActor getActor() {
        checkNotNull();
        return PxRigidActor.wrapPointer(_getActor(address));
    }
    private static native long _getActor(long address);

    /**
     * @param value WebIDL type: {@link PxRigidActor}
     */
    public void setActor(PxRigidActor value) {
        checkNotNull();
        _setActor(address, value.getAddress());
    }
    private static native void _setActor(long address, long value);

    /**
     * @return WebIDL type: {@link PxShape}
     */
    public PxShape getShape() {
        checkNotNull();
        return PxShape.wrapPointer(_getShape(address));
    }
    private static native long _getShape(long address);

    /**
     * @param value WebIDL type: {@link PxShape}
     */
    public void setShape(PxShape value) {
        checkNotNull();
        _setShape(address, value.getAddress());
    }
    private static native void _setShape(long address, long value);

}
